<html>
<head>
<title>img0ch - u<?cs var:html_escape(BBS_TITLE) ?>v̓Ytt@CǗ</title>
<meta http-equiv="Content-Type" content="text/html; charset=ShiftJIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<meta name="Robot" content="NOINDEX,NOFOLLOW">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
//-->
</script>
<style type="text/css">
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
/* from zeromin2.css */
.noticeFailed {
  margin: 1em 0;
  padding: 0 2.5em;
  color: #ff0000;
  background: #ffeeee;
  border: 1px solid #ff9999;
}
.noticeSuccess {
  margin: 1em 0;
  padding: 0 2.5em;
  color: #008000;
  background: #eeffee;
  border: 1px solid #99ff99;
}
<?cs var:TagCloudCSS ?>
</style>
<?cs var:META ?>
</head>
<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><hr><?cs /if ?>
<?cs if:Password ?>
<?cs if:Removed ?><div class="noticeSuccess" id="notify"><p>w肳ꂽt@C폜܂</p></div><?cs /if ?>
<?cs if:Failed ?><div class="noticeFailed" id="notify"><p>w肳ꂽt@C̑삪o܂<br>pX[hԈĂ邩Aݒ肳Ă܂</p></div><?cs /if ?>
<?cs /if ?>
<?cs if:TaggedOK ?><div class="noticeSuccess" id="notify"><p>Ytt@C̃^Ot܂</p></div>
<?cs elif:TaggedNG ?><div class="noticeFailed" id="notify"><p>ȉ̂ЂƂȏY邽ߓYtt@C̃^Oto܂ł<ul><li>Ǘ҂ɂă^Ot@\~Ă</li><li>evNVoR܂͋KĂ</li></ul></p></div>
<?cs /if ?>
<?cs if:RatedOK ?><div class="noticeSuccess" id="notify"><p>Ytt@C̕]܂</p></div>
<?cs elif:RatedNG ?><div class="noticeFailed" id="notify"><p>ȉ̂ЂƂȏY邽ߓYtt@C̕]o܂ł<ul><li>Rg</li><li>evNVoR܂͋KĂ</li><li>ɂ̓Ytt@Cɑ΂ē[ς</li></ul></p></div>
<?cs /if ?>
<?cs if:PolledOK ?><div class="noticeSuccess" id="notify"><p>Ytt@C̒~[܂<br><?cs if:Freezed ?>܂A[<?cs var:html_escape(BBS_IMG_POLL_REQUIRE_TO_STOP) ?>[B߁AYtt@C̓s܂<?cs /if ?></p></div>
<?cs elif:PolledNG ?><div class="noticeFailed" id="notify"><p>ȉ̂ЂƂȏY邽ߓYtt@C̒~[o܂ł<ul><li>Rg</li><li>evNVoR܂͋KĂ</li><li>[\𒴂Ă</li><li>ɂ̓Ytt@Cɑ΂ē[ς</li></ul></p></div>
<?cs /if ?>
<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<tr><td>
<form action="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>" method="post">
<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">Ytt@C</a>
<?cs if:KEY ?><a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/l50" onclick="redir(this)">Xbhɖ߂</a>
<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">zXbhǗ</a><?cs /if ?>
<br>
<select name="key">
<?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"<?cs if:item.selected ?> selected<?cs /if ?>><?cs var:item.subject ?> (<?cs var:html_escape(item.res) ?>)</option>
<?cs /each ?></select><br>
<table border="0">
<tr><td><label for="it_resno">Xԍ</label></td><td><input id="it_resno" name="resno" type="text" value="<?cs var:html_escape(Resno) ?>" size="5"></td></tr>
<tr><td><label for="ip_password">pX[h</label></td><td><input id="ip_password" name="pass" type="password"></td></tr>
</table>
<input id="ir_remove" type="radio" name="type" value="remove" checked><label for="ir_remove">폜</label>
<input id="ir_download" type="radio" name="type" value="download"><label for="ir_download">_E[h</label>
<br>
<input type="submit" value="M">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
</form>
</td></tr>
</table>
<?cs if:Resno ?>
<br>
<table border="1" align="center" cellspacing="7" cellpadding="3" width="" bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>">
<tr><td>
<h3>Ytt@Cɂꂽ^O</h3>
<?cs var:TagCloudHTML ?>
<form action="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/<?cs var:html_escape(Resno) ?>" method="post">
<p>
^O̓Xy[Xŋ؂ē͂Kv܂B<br />
^O1ɂő<?cs var:html_escape(TagMaxLength) ?>oCgA10܂Ŏwł܂B<br />
</p>
<p align="center">
<input type="text" name="tag" value="<?cs var:html_escape(MyTags) ?>" size="80">
<input type="submit" value="^Ot">
<input type="hidden" name="type" value="tagging">
</p>
</form>
</td></tr>
<tr><td>
<h3>Ytt@C̕ϕ]&nbsp;-&nbsp;<?cs var:html_escape(RateAverage) ?></h3>
<dl>
<form action="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/<?cs var:html_escape(Resno) ?>" method="post">
<p>IP̘A]͏o܂B</p>
<?cs each:item = Reviews ?>
<dt><?cs var:html_escape(item.resno) ?> ]ҁF<b><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs if:DisplayPolledIP ?><?cs var:html_escape(item.ip) ?><?cs else ?>J<?cs /if ?></font></b>(<?cs var:html_escape(item.rate) ?>)F<?cs var:html_escape(item.reviewed) ?></dt>
<dd><?cs var:html_escape(item.comment) ?></dd>
<?cs /each ?>
<p align="center">
<input type="text" name="comment" size="80"><br>
<select name="rate">
<option value="5">:5</option>
<option value="4">:4</option>
<option value="3">:3</option>
<option value="2">:2</option>
<option value="1">:1</option>
</select>
<input type="submit" value="]">
<input type="hidden" name="type" value="rate">
</p>
</form>
</dl></td></tr>
</td></tr>
<tr><td><dl>
<form action="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/<?cs var:html_escape(Resno) ?>" method="post">
<p>
Ytꂽt@CK؂Ŗꍇ̓Rgāu~[vsĂB<br>
[<strong><?cs var:html_escape(BBS_IMG_POLL_REQUIRE_TO_STOP) ?>[ȏ</strong>ŉ{yу_E[h~܂B<br>
[҂<strong>IPAhX͌J<?cs if:DisplayPolledIP ?>܂<?cs else ?>܂<?cs /if ?></strong>B<br>
<?cs if:PollableCount ?>_ł<strong><?cs var:html_escape(PollableCount) ?>񓊕[o܂</strong>B0ɂȂƓ[oȂȂ܂B<?cs else ?>[\ɒBߌݓ[o܂B΂炭Ɠ[\ɂȂ܂B<?cs /if ?>
</p>
<?cs each:item = PollForBad ?>
<dt><?cs var:html_escape(item.resno) ?> [ҁF<b><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs if:DisplayPolledIP ?><?cs var:html_escape(item.ip) ?><?cs else ?>J<?cs /if ?></font></b>F<?cs var:html_escape(item.polled) ?></dt>
<dd><?cs var:html_escape(item.comment) ?></dd>
<?cs /each ?>
<p align="center">
<input type="text" name="comment" size="80">
<input type="submit" value="~[s">
<input type="hidden" name="type" value="poll">
<p>
</form>
</dl></td></tr>
</table>
<?cs /if ?>
<div id="footer" align="right"><a href="http://img0ch.sourceforge.jp">img0ch-ufm.cgi - img0ch BBS</a></div>
</body>
</html>
